@@ -1,20 +1,14 @@
-require "sentry/rails/instrument_payload_cleanup_helper"
-
 module Sentry
   module Rails
     module Breadcrumb
       module ActiveSupportLogger
         class << self
-          include InstrumentPayloadCleanupHelper
-
           def add(name, started, _finished, _unique_id, data)
             # skip Rails' internal events
             return if name.start_with?("!")
 
             if data.is_a?(Hash)
-              # we should only mutate the copy of the data
-              data = data.dup
-              cleanup_data(data)
+              data = data.slice(*@allowed_keys[name])
             end
 
             crumb = Sentry::Breadcrumb.new(
@@ -25,7 +19,9 @@ module Sentry
             Sentry.add_breadcrumb(crumb)
           end
 
-          def inject
+          def inject(allowed_keys)
+            @allowed_keys = allowed_keys
+
             @subscriber = ::ActiveSupport::Notifications.subscribe(/.*/) do |name, started, finished, unique_id, data|
               # we only record events that has a started timestamp
               if started.is_a?(Time)
