@@ -8,14 +8,20 @@ module Sentry
         extend InstrumentPayloadCleanupHelper
 
         EVENT_NAMES = ["process_action.action_controller"].freeze
+        OP_NAME = "view.process_action.action_controller".freeze
 
         def self.subscribe!
+          Sentry.logger.warn <<~MSG
+            DEPRECATION WARNING: sentry-rails has changed its approach on controller span recording and #{self.name} is now depreacted.
+            Please stop using or referencing #{self.name} as it will be removed in the next major release.
+          MSG
+
           subscribe_to_event(EVENT_NAMES) do |event_name, duration, payload|
             controller = payload[:controller]
             action = payload[:action]
 
             record_on_current_span(
-              op: event_name,
+              op: OP_NAME,
               start_timestamp: payload[START_TIMESTAMP_NAME],
               description: "#{controller}##{action}",
               duration: duration
